@@ -13,6 +13,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+
 from pynetbox.core.query import Request, RequestError
 from pynetbox.core.response import Record, RecordSet
 
@@ -323,7 +324,7 @@ class Endpoint:
 
         >>> device = netbox.dcim.devices.create(
         ...    name='test',
-        ...    device_role=1,
+        ...    role=1,
         ... )
         >>>
 
@@ -344,14 +345,14 @@ class Endpoint:
         >>> nb.dcim.devices.create([
         ...     {
         ...         "name": "test1-core3",
-        ...         "device_role": 3,
+        ...         "role": 3,
         ...         "site": 1,
         ...         "device_type": 1,
         ...         "status": 1
         ...     },
         ...     {
         ...         "name": "test1-core4",
-        ...         "device_role": 3,
+        ...         "role": 3,
         ...         "site": 1,
         ...         "device_type": 1,
         ...         "status": 1
@@ -458,7 +459,9 @@ class Endpoint:
         series = []
         if not isinstance(objects, list):
             raise ValueError(
-                "Objects passed must be list[dict|Record] - was " + type(objects)
+                "Objects passed must be list[dict|Record] - was {}".format(
+                    type(objects)
+                )
             )
         for o in objects:
             if isinstance(o, Record):
@@ -472,7 +475,7 @@ class Endpoint:
                 series.append(o)
             else:
                 raise ValueError(
-                    "Object passed must be dict|Record - was " + type(objects)
+                    "Object passed must be dict|Record - was {}".format(type(objects))
                 )
         req = Request(
             base=self.url,
