@@ -13,6 +13,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+
 import copy
 from collections import OrderedDict
 
@@ -226,7 +227,7 @@ class Record:
      'config_context': {},
      'created': '2018-04-01',
      'custom_fields': {},
-     'device_role': {'id': 1,
+     'role': {'id': 1,
                      'name': 'Test Switch',
                      'slug': 'test-switch',
                      'url': 'http://localhost:8000/api/dcim/device-roles/1/'},
@@ -413,6 +414,9 @@ class Record:
                 if len(v) and isinstance(v[0], dict) and "object_type" in v[0]:
                     v = [generic_list_parser(k, i) for i in v]
                     to_cache = list(v)
+                elif k == "constraints":
+                    # Permissions constraints can be either dict or list
+                    to_cache = copy.deepcopy(v)
                 else:
                     v = [list_parser(k, i) for i in v]
                     to_cache = list(v)
